@@ -2,13 +2,15 @@
 
 # $2 version
 # $3 original tarball
-TAR=$3
-DIR=uimaj-$2-*
+ZIP=$3
+TAR=uimaj_$2.orig.tar.gz
+DIR=uimaj-$2
 
 # clean up the upstream tarball
-tar xvzf $TAR
+unzip $ZIP
 GZIP=--best tar -c -z -f $TAR -X debian/orig-tar.exclude $DIR
 rm -rf $DIR
+rm $3
 
 # move to directory 'tarballs'
 if [ -r .svn/deb-layout ]; then
